import { Module, Provider } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { DIRECTION_ENCODER, PARAMS_PROVIDER } from './geography.di-tokens';
import { DefaultParamsProvider } from './infrastructure/default-params-provider';
import { PostgresDirectionEncoder } from './infrastructure/postgres-direction-encoder';
import { GetBasicRouteController } from './interface/controllers/get-basic-route.controller';
import { RouteMapper } from './route.mapper';

const mappers: Provider[] = [RouteMapper];

const adapters: Provider[] = [
  {
    provide: PARAMS_PROVIDER,
    useClass: DefaultParamsProvider,
  },
  {
    provide: DIRECTION_ENCODER,
    useClass: PostgresDirectionEncoder,
  },
  GetBasicRouteController,
];

@Module({
  imports: [CqrsModule],
  providers: [...mappers, ...adapters],
  exports: [RouteMapper, DIRECTION_ENCODER, GetBasicRouteController],
})
export class GeographyModule {}
