import { ArgumentOutOfRangeException } from '@mobicoop/ddd-library';
import { Coordinates } from '@modules/geography/core/domain/value-objects/coordinates.value-object';

describe('Waypoint value object', () => {
  it('should create a waypoint value object', () => {
    const coordinatesVO = new Coordinates({
      lon: 48.689445,
      lat: 6.17651,
    });
    expect(coordinatesVO.lon).toBe(48.689445);
    expect(coordinatesVO.lat).toBe(6.17651);
  });
  it('should throw an exception if longitude is invalid', () => {
    try {
      new Coordinates({
        lon: 348.689445,
        lat: 6.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
    try {
      new Coordinates({
        lon: -348.689445,
        lat: 6.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
  });
  it('should throw an exception if latitude is invalid', () => {
    try {
      new Coordinates({
        lon: 48.689445,
        lat: 96.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
    try {
      new Coordinates({
        lon: 48.689445,
        lat: -96.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
  });
});
